## SCENARIO 7: Error DP, mocked

### INPUTS

#### GROUP 1: Event Sequence

# | Set Name | Timer Name | Event | Elapsed Time | CPU Time
--- | --- | --- | --- | --- | ---
1 | Set 1 |  | CON | 3.000 | .800
2 | Set 1 | Timer 1 | INC | 33.123 | 9.256
3 | Set 1 |  | GETF | 63.246 | 17.712

####

#### GROUP 2: Scalars

# | Mock Flag | Time Width | Decimal Places (Totals) | Decimal Places (per call) | Calls Width
--- | --- | --- | --- | --- | ---
1 | Y | 4 | 1 | 3 | 5

####

### OUTPUTS

#### GROUP 1: Set 1: Empty as expected: SUCCESS

#### GROUP 2: Set 1 (formatted): Empty as expected: SUCCESS

#### GROUP 3: Set 2: Empty as expected: SUCCESS

#### GROUP 4: Set 2 (formatted): Empty as expected: SUCCESS

#### GROUP 5: Self (unmocked): Empty as expected: SUCCESS

#### GROUP 6: Self (unmocked, formatted): Empty as expected: SUCCESS

#### GROUP 7: Results: Empty as expected: SUCCESS

#### GROUP 8: Exception

# | 1 Message, 2 Stack
--- | ---
1 | Error, time_width + time_dp must be > 6, actual: 4 + 1
2 | UNTESTED: Traceback (most recent call last): File "./test/testtimerset.py", line 109, in purely_wrap_unit dp_per_call, calls_width) File "C:\Users\Brend_000\OneDrive\Script\pip\timerset\timerset\timerset.py", line 168, in format_timers time_width, time_dp, time_ratio_dp, calls_width) File "C:\Users\Brend_000\OneDrive\Script\pip\timerset\timerset\timerset.py", line 70, in _val_widths format(actual=str(time_width) + ' + ' + str(time_dp))) ValueError: Error, time_width + time_dp must be > 6, actual: 4 + 1

#### 0 failed of 2: SUCCESS

## 0 failed of 8: SUCCESS